@@ -8,7 +8,7 @@
  *
  * @package    Magic3 Framework
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
- * @copyright  Copyright 2006-2016 Magic3 Project.
+ * @copyright  Copyright 2006-2017 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
  * @version    SVN: $Id$
  * @link       http://www.magic3.org
@@ -23,11 +23,13 @@ class AnalyzeManager extends Core
 	const NOT_FOUND_BROWSER_IMAGE = 'noimage.png';			// ブラウザアイコンが見つからなかった場合のアイコン
 	const CF_LAST_DATE_CALC_PV	= 'last_date_calc_pv';	// ページビュー集計の最終更新日
 	const MAX_CALC_DAYS = 30;					// 最大集計日数
-//	const CRAWLER_DETECT_SCRIPT_DIR = '/Crawler-Detect-1.2.2/';		// クローラー解析スクリプトディレクトリ
-	const CRAWLER_DETECT_SCRIPT_DIR = '/Crawler-Detect-1.2.20/';		// クローラー解析スクリプトディレクトリ
+//	const CRAWLER_DETECT_SCRIPT_DIR = '/Crawler-Detect-1.2.20/';		// クローラー解析スクリプトディレクトリ
+	const CRAWLER_DETECT_SCRIPT_DIR = '/Crawler-Detect-1.2.40/';		// クローラー解析スクリプトディレクトリ
 	const USER_AGENT_SCRIPT = '/Net_UserAgent_Mobile-1.0.0/Net/UserAgent/Mobile.php';		// ユーザエージェント解析用スクリプト
-	const BROWSER_DETECT_SCRIPT = '/PhpUserAgent-0.5.2/UserAgentParser.php';		// ブラウザ判定スクリプト
-	const PLATFORM_DETECT_SCRIPT_DIR = '/php-browser-detector-6.0.5/';		// プラットフォーム判定スクリプト
+//	const BROWSER_DETECT_SCRIPT = '/PhpUserAgent-0.5.2/UserAgentParser.php';		// ブラウザ判定スクリプト
+	const BROWSER_DETECT_SCRIPT = '/PhpUserAgent-0.7.0/UserAgentParser.php';		// ブラウザ判定スクリプト
+//	const PLATFORM_DETECT_SCRIPT_DIR = '/php-browser-detector-6.0.5/';		// プラットフォーム判定スクリプト
+	const PLATFORM_DETECT_SCRIPT_DIR = '/php-browser-detector-6.1.2/';		// プラットフォーム判定スクリプト
 	
 	/**
 	 * コンストラクタ
@@ -574,6 +576,7 @@ $agent = 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like G
 			'msnbot'					=> 'msn.gif',	// MSN
 			'msnbot-media'				=> 'msn.gif',	// MSN
 			'yahooseeker'				=> 'yahoo.gif',	// YahooSeeker
+			'slurp'						=> 'yahoo.gif',	// Yahoo!
 			'yahoo! de slurp'			=> 'yahoo.gif',	// Yahoo!
 			'yahoo! slurp'				=> 'yahoo.gif',	// Yahoo!
 			'zyborg'					=> '',	// InfoSeek
@@ -593,11 +596,13 @@ $agent = 'Mozilla/5.0 (Windows NT 10.0; WOW64) AppleWebKit/537.36 (KHTML, like G
 			'speedy spider'				=> 'entireweb.png',	// Entireweb
 			'turnitinbot'				=> 'turnitinbot.png',	// TurnitinBot
 			'bingbot'					=> 'bing.png',	// Bing
+			'bingpreview'				=> 'bing.png',	// Bing
 			'yacybot'					=> 'yacy.png',	// YaCy
 			'mj12bot'					=> 'mj12bot.png',
 			'ahrefsbot'					=> 'ahrefs.png',
 			'semrushbot'				=> 'semrush.png',
 			'scrapy'					=> 'scrapy.png',
+			'deusu'						=> 'deusu.png',
 			
 			// クローラーその他
 			'msproxy'					=> '',	// ProxyServer
