@@ -567,9 +567,9 @@ class admin_mainTemplistWidgetContainer extends admin_mainTempBaseWidgetContaine
 		$eventAttr = 'onclick="previewInOtherWindow(\'' . $templateId . '\');"';
 		$previewButtonTag = $this->gDesign->createPreviewButton(''/*同画面*/, $this->_('Preview'), ''/*タグID*/, $eventAttr/*クリックイベント時処理*/);
 		// ダウンロードボタン
-		$downloadDisabled = '';// ボタンの状態
-		if (!$isExistsTemplate) $downloadDisabled = 'disabled';
-		$downloadImg = $this->getUrl($this->gEnv->getRootUrl() . self::DOWNLOAD_ZIP_ICON_FILE);
+		$downloadDisabled = false;// ボタンの状態
+		if (!$isExistsTemplate) $downloadDisabled = true;
+/*		$downloadImg = $this->getUrl($this->gEnv->getRootUrl() . self::DOWNLOAD_ZIP_ICON_FILE);
 		if (empty($downloadDisabled)){
 			$downloadStr = 'ダウンロード';
 		} else {
@@ -577,6 +577,9 @@ class admin_mainTemplistWidgetContainer extends admin_mainTempBaseWidgetContaine
 		}
 		$downloadButtonTag = '<img src="' . $downloadImg . '" width="32" height="32" alt="' . $downloadStr . '" />';
 		$downloadButtonTag = '<a class="btn btn-xs" href="javascript:void(0);" onclick="downloadTemplate(\'' . $templateId . '\');" rel="m3help" data-container="body" title="' . $downloadStr . '" ' . $downloadDisabled . '>' . $downloadButtonTag . '</a>';
+		*/
+		$eventAttr = 'onclick="downloadTemplate(\'' . $templateId . '\');"';
+		$downloadButtonTag = $this->gDesign->createDownloadButton(''/*同画面*/, $this->_('.zip Download'), ''/*タグID*/, $eventAttr/*クリックイベント時処理*/, $downloadDisabled/*ボタン使用可否*/);
 		// テンプレート編集ボタン
 		$editDisabled = '';// ボタンの状態
 		$editUrl = '?task=' . self::TASK_TEMPIMAGE . '&' . M3_REQUEST_PARAM_TEMPLATE_ID . '=' . $templateId;	// テンプレート編集画面
@@ -585,7 +588,13 @@ class admin_mainTemplistWidgetContainer extends admin_mainTempBaseWidgetContaine
 			$editDisabled = 'disabled';
 			$editUrl = '';
 		}
-		$editButtonTag = $this->gDesign->createEditButton($editUrl, $this->_('Edit Template'), ''/*タグID*/, $editDisabled/*ボタン状態*/);
+//		$editButtonTag = $this->gDesign->createEditButton($editUrl, $this->_('Edit Template'), ''/*タグID*/, $editDisabled/*ボタン状態*/);
+		
+		// テンプレートCSS生成ボタン
+		$generateCssUrl = '?task=' . self::TASK_TEMPGENERATECSS . '&' . M3_REQUEST_PARAM_TEMPLATE_ID . '=' . $templateId;	// テンプレートCSS生成画面
+		$generateDisabled = '';
+		$canGenerateCss = $this->canGenerateCss($templateId);
+		if (!$canGenerateCss) $generateDisabled = 'class="disabled"';
 		
 		$row = array(
 			'no'			=> $index + 1,													// 行番号
@@ -601,7 +610,11 @@ class admin_mainTemplistWidgetContainer extends admin_mainTempBaseWidgetContaine
 			'delete_button'		=> $deleteButtonTag,		// 削除ボタン
 			'preview_button'	=> $previewButtonTag,		// プレビューボタン
 			'download_button' 	=> $downloadButtonTag,		// ダウンロードボタン
-			'edit_button' 		=> $editButtonTag			// テンプレート編集ボタン
+//			'edit_button' 		=> $editButtonTag,			// テンプレート編集ボタン
+			'edit_disabled'		=> $editDisabled,		// テンプレート編集ボタンの使用可否
+			'edit_url'			=> $editUrl,				// テンプレート画像編集用URL
+			'generate_css_url'	=> $generateCssUrl,			// テンプレートCSS生成用URL
+			'generate_disabled'	=> $generateDisabled		// CSS生成ボタンの使用可否
 		);
 		$this->tmpl->addVars('templist', $row);
 		$this->tmpl->parseTemplate('templist', 'a');
@@ -701,6 +714,38 @@ class admin_mainTemplistWidgetContainer extends admin_mainTempBaseWidgetContaine
 		}
 		return $id;
 	}
+	/**
+	 * CSS生成可能か判断
+	 *
+	 * @param string $id		テンプレートID
+	 * @return bool				true=CSS生成可能、false=CSS生成不可
+	 */
+	function canGenerateCss($id)
+	{
+		$canGenerate = false;		// 生成可否
+		
+		$configFile = $this->gEnv->getTemplatesPath() . '/' . $id . '/' . self::JOOMLA_CONFIG_FILENAME;
+		if (file_exists($configFile)){
+			if (!function_exists('simplexml_load_file')){
+				$msg = $this->_('SimpleXML module not installed.');		// SimpleXML拡張モジュールがインストールされていません
+				$this->setAppErrorMsg($msg);
+				return false;
+			}
+			$xml = simplexml_load_file($configFile);
+			if ($xml !== false){
+				if ($xml->attributes()->type == 'template'){
+					$version = $xml->attributes()->version;
+					$format = $xml->attributes()->format;
+					
+					$less = $xml->develop->less;
+//					$sass = $xml->develop->sass;
+//					$scss = $xml->develop->scss;
+					if (!empty($less)) $canGenerate = true;
+				}
+			}
+		}
+		return $canGenerate;
+	}
 	/**
 	 * タイプ選択メニュー作成
 	 *
